==> azure_data_cosmos-0.1.0.crate: azure_data_cosmos-0.1.0/src/resources/document/indexing_directive.rs <==
use crate::headers;
use azure_core::ParseError;
use http::request::Builder;
use std::fmt;

/// Whether the resource should be included in the index.
#[derive(Debug, Clone, Copy, PartialEq)]
pub enum IndexingDirective {
    /// Follow the default indexing policy for the collection.
    Default,
    /// Add the resource to the index.
    Include,
    /// Omit the resource to the index.
    Exclude,
}

impl<'a> From<&'a IndexingDirective> for &'a str {
    fn from(s: &'a IndexingDirective) -> &'a str {
        match s {
            IndexingDirective::Default => "Default",
            IndexingDirective::Exclude => "Exclude",
            IndexingDirective::Include => "Include",
        }
    }
}

impl std::str::FromStr for IndexingDirective {
    type Err = ParseError;

    fn from_str(s: &str) -> Result<Self, Self::Err> {
        match s {
            "Default" => Ok(IndexingDirective::Default),
            "Exclude" => Ok(IndexingDirective::Exclude),
            "Include" => Ok(IndexingDirective::Include),
            _ => Err(ParseError::UnknownVariant {
                item: "IndexingDirective",
                variant: s.to_owned(),
            }),
        }
    }
}

impl fmt::Display for IndexingDirective {
    fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
        write!(f, "{:?}", self)
    }
}

impl azure_core::AddAsHeader for IndexingDirective {
    fn add_as_header(&self, builder: Builder) -> Builder {
        match self {
            IndexingDirective::Default => builder,
            IndexingDirective::Exclude => {
                builder.header(headers::HEADER_INDEXING_DIRECTIVE, "Exclude")
            }
            IndexingDirective::Include => {
                builder.header(headers::HEADER_INDEXING_DIRECTIVE, "Include")
            }
        }
    }

    fn add_as_header2(
        &self,
        request: &mut azure_core::Request,
    ) -> Result<(), azure_core::HttpHeaderError> {
        let (header_name, header_value) = match self {
            IndexingDirective::Default => return Ok(()),
            IndexingDirective::Exclude => (headers::HEADER_INDEXING_DIRECTIVE, "Exclude"),
            IndexingDirective::Include => (headers::HEADER_INDEXING_DIRECTIVE, "Include"),
        };

        request.headers_mut().append(
            header_name,
            http::header::HeaderValue::from_str(header_value)?,
        );
        Ok(())
    }
}

==> azure_data_cosmos-0.2.0.crate: azure_data_cosmos-0.2.0/src/resources/document/indexing_directive.rs <==
use azure_core::headers::{self, AsHeaders};
use azure_core::ParseError;
use std::fmt;

/// Whether the resource should be included in the index.
#[derive(Debug, Clone, Copy, PartialEq)]
pub enum IndexingDirective {
    /// Follow the default indexing policy for the collection.
    Default,
    /// Add the resource to the index.
    Include,
    /// Omit the resource to the index.
    Exclude,
}

impl<'a> From<&'a IndexingDirective> for &'a str {
    fn from(s: &'a IndexingDirective) -> &'a str {
        match s {
            IndexingDirective::Default => "Default",
            IndexingDirective::Exclude => "Exclude",
            IndexingDirective::Include => "Include",
        }
    }
}

impl std::str::FromStr for IndexingDirective {
    type Err = ParseError;

    fn from_str(s: &str) -> Result<Self, Self::Err> {
        match s {
            "Default" => Ok(IndexingDirective::Default),
            "Exclude" => Ok(IndexingDirective::Exclude),
            "Include" => Ok(IndexingDirective::Include),
            _ => Err(ParseError::UnknownVariant {
                item: "IndexingDirective",
                variant: s.to_owned(),
            }),
        }
    }
}

impl fmt::Display for IndexingDirective {
    fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
        write!(f, "{:?}", self)
    }
}

impl AsHeaders for IndexingDirective {
    type Iter = std::vec::IntoIter<(headers::HeaderName, headers::HeaderValue)>;

    fn as_headers(&self) -> Self::Iter {
        match self {
            IndexingDirective::Default => vec![].into_iter(),
            IndexingDirective::Exclude => vec![(
                crate::headers::HEADER_INDEXING_DIRECTIVE.into(),
                "Exclude".into(),
            )]
            .into_iter(),
            IndexingDirective::Include => vec![(
                crate::headers::HEADER_INDEXING_DIRECTIVE.into(),
                "Include".into(),
            )]
            .into_iter(),
        }
    }
}
